# coding: utf-8

"""
    OurSky SDA

    The basic flow for a new organization is as follows: 1. View the available satellite targets with the [satellite targets](#tag/satellite-targets/[get]/v1/satellite-targets) endpoint. Copy the id of the target you want to observe. 2. Create an organization target with the [organization target](#tag/organization-targets/[get]/v1/organization-targets) endpoint. Use the id copied from above. 3. Create a webhook with the [webhook](#tag/webhooks/[post]/v1/communications/webhook) endpoint to receive TDMs automatically (preferred) or use the [tdms](#tag/tdms/[get]/v1/tdms) endpoint to poll for TDMs.

    The version of the OpenAPI document: 1.3.3700
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from ourskyai_sda_api.models.orbit_type import OrbitType
from ourskyai_sda_api.models.weather_condition import WeatherCondition

class V1SatellitePotential(BaseModel):
    """
    SatellitePotential  # noqa: E501
    """
    first_observable_time: datetime = Field(..., alias="firstObservableTime")
    last_observable_time: datetime = Field(..., alias="lastObservableTime")
    satellite_target_id: Optional[StrictStr] = Field(None, alias="satelliteTargetId")
    norad_id: Optional[StrictStr] = Field(None, alias="noradId")
    orbit_type: Optional[OrbitType] = Field(None, alias="orbitType")
    weather_condition: Optional[WeatherCondition] = Field(None, alias="weatherCondition")
    weather_description: Optional[StrictStr] = Field(None, alias="weatherDescription")
    __properties = ["firstObservableTime", "lastObservableTime", "satelliteTargetId", "noradId", "orbitType", "weatherCondition", "weatherDescription"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1SatellitePotential:
        """Create an instance of V1SatellitePotential from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1SatellitePotential:
        """Create an instance of V1SatellitePotential from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return V1SatellitePotential.parse_obj(obj)

        _obj = V1SatellitePotential.parse_obj({
            "first_observable_time": obj.get("firstObservableTime"),
            "last_observable_time": obj.get("lastObservableTime"),
            "satellite_target_id": obj.get("satelliteTargetId"),
            "norad_id": obj.get("noradId"),
            "orbit_type": obj.get("orbitType"),
            "weather_condition": obj.get("weatherCondition"),
            "weather_description": obj.get("weatherDescription")
        })
        return _obj


